==> CSET-0.1.0.tar.gz: CSET-0.1.0/README.md <==
# CSET

CSET is a tool to aid in evaluating regional model configurations. It aims to
replace the collection of bespoke scripts littering people’s home directories,
reducing effort wasted on duplicating already existing code. This centralisation
of diagnostics should also make evaluations more consistent and comparable.
Development takes place in the CSET repository on GitHub.

Please read [the documentation](https://metoffice.github.io/CSET) to learn more
about CSET, and how to use it.

## Contributing

Contributions are readily welcomed! To get started with developing CSET visit
the [Working
Practices](https://metoffice.github.io/CSET/working-practices/#getting-started)
section of the documentation.

In addition to reading the working practices, the key
recommendation is early communication. Open an [issue on
Github](https://github.com/MetOffice/CSET/issues) with your proposed change or
addition in the design phase, and then others can provide guidance early.

## Licence

Copyright © 2022-2023 Met Office and contributors.

Licensed under the [Apache License, Version 2.0](LICENCE) (the "License"); You
may obtain a copy of the License at

<http://www.apache.org/licenses/LICENSE-2.0>

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.

==> CSET-0.3.0.tar.gz: CSET-0.3.0/README.md <==
# CSET

CSET is a toolkit for evaluation and investigation of numerical models for
weather and climate applications. It aims to replace the collection of bespoke
scripts littering people’s home directories, reducing effort wasted on
duplicating already existing code. This centralisation of diagnostics should
also make evaluations more consistent and comparable. Development takes place in
the CSET repository on GitHub.

Please read [the documentation](https://metoffice.github.io/CSET) to learn more
about CSET, and how to use it.

## Contributing

Contributions are readily welcomed! To get started with developing CSET visit
the [Contributing](https://metoffice.github.io/CSET/contributing/) section of
the documentation.

In addition to reading the working practices, the key
recommendation is early communication. Open an [issue on
Github](https://github.com/MetOffice/CSET/issues) with your proposed change or
addition in the design phase, and then others can provide guidance early.

## Licence

Copyright © 2022-2023 Met Office and contributors.

Licensed under the [Apache License, Version 2.0](LICENCE) (the "License"); You
may obtain a copy of the License at

<http://www.apache.org/licenses/LICENSE-2.0>

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
